# PyEgyBest

**This Project Has Been Discontinued**

This is a Selenium-less Python Library that allows you to interact with EgyBest

## Installation

You can simply install the library from PyPI with this command:

```bash
pip install egybest

```
